@@ -488,7 +488,7 @@ ypresp_val *ypproc_match_2_svc(ypreq_key *key,
 	    if (debug_flag)
 		fprintf(stderr, "\t-> OK (%s/%s)\n",
 			he->h_name,
-			inet_ntoa(* (struct in_addr *) &he->h_addr));
+			inet_ntoa(* (struct in_addr *) he->h_addr));
 
 	    len = 16; /* Numerical IP address */
 	    len += strlen(he->h_name) + 1;
@@ -497,7 +497,7 @@ ypresp_val *ypproc_match_2_svc(ypreq_key *key,
 	    
 
 	    cp = malloc(len+1);
-	    strcpy(cp, inet_ntoa(* (struct in_addr *) &he->h_addr));
+	    strcpy(cp, inet_ntoa(* (struct in_addr *) he->h_addr));
 	    strcat(cp, " ");
 	    strcat(cp, he->h_name);
 
